@@ -289,7 +289,7 @@ class Dataset(object):
                 well_df, new_cols, curves_to_scale = self._process_well(well_df, **kwargs.get('_process_well', {}))
                 if 'time_features' in kwargs.keys():
                     time_cols   = [c for c in df.columns if c != self.id_column and c != self.label_column]
-                    well_df, time_cols = feature_helpers._add_time_features(well_df, tim_cols, kwargs['time_features'])
+                    well_df, time_cols = feature_helpers._add_time_features(well_df, time_cols, kwargs['time_features'])
                 res_df = res_df.append(well_df)
             df = res_df.copy()
             curves_to_scale = curves_to_scale + time_cols if time_cols!=None else curves_to_scale
@@ -476,13 +476,17 @@ class Dataset(object):
         if columns is None:
             columns = self.cat_columns
         if 'FORMATION' in columns:
+            df['FORMATION'] = df['FORMATION'].apply(lambda x: helpers._standardize_group_formation_name(x))
             df['FORMATION'] = df['FORMATION'].map(self.formations_map)
-
+            df['FORMATION'] = df['FORMATION'].apply(lambda x: -1 if (x not in self.formations_map.values()) else x)
         if 'GROUP' in columns:
+            df['GROUP'] = df['GROUP'].apply(lambda x: helpers._standardize_group_formation_name(x))
             df['GROUP'] = df['GROUP'].map(self.groups_map)
-
+            df['GROUP'] = df['GROUP'].apply(lambda x: -1 if (x not in self.groups_map.values()) else x)
         if 'lsuName' in columns:
+            df['lsuName'] = df['lsuName'].apply(lambda x: helpers._standardize_group_formation_name(x))
             df['lsuName'] = df['lsuName'].map(self.groups_map)
+            df['lsuName'] = df['lsuName'].apply(lambda x: -1 if (x not in self.groups_map.values()) else x)
 
         return df
 
